@@ -24,6 +24,13 @@ import template
 _DB = seqdb.get()
 
 def get_mnemonic(direction, prefix, p, i, f):
+    '''
+      >>> _create_mock_db()
+      >>> get_mnemonic('<', '?', '1;2', '', 'c')
+      'DA1 Response'
+      >>> get_mnemonic('<', '', '32;41;42', '', 'M')
+      'urxvt (1015) mouse reporting (code=(32-32),row=41,col=42)'
+    '''
 
     params = p.split(";")
 
@@ -60,6 +67,13 @@ def get_mnemonic(direction, prefix, p, i, f):
 
 
 def format(parameter, intermediate, final, is_input, tracer, controller):
+    '''
+      >>> _create_mock_db()
+      >>> template.disable_color()
+      >>> format([0x3f, 0x31, 0x3b, 0x32], [], 0x63, True, None, None)
+      ' CSI ?1;2c    DA1 Response'
+    '''
+
     p = ''.join([chr(c) for c in parameter])
     i = ''.join([chr(c) for c in intermediate]).replace(" ", "<SP>")
     f = chr(final)
@@ -80,6 +94,19 @@ def format(parameter, intermediate, final, is_input, tracer, controller):
 
     return template.getcsi() % (p, i, f, mnemonic)
 
+def _create_mock_db():
+    global _DB
+    _DB = {
+      '< CSI A'            : 'Cursor key(normal keypad): up arrow',
+      '< CSI 1;5A'         : 'Cursor key (xterm): Ctrl + up arrow',
+      '< CSI [0]M'         : 'xterm normal mouse reporting, following 3 bytes mean (code, row, col)',
+      '< CSI [3]M'         : 'urxvt (1015) mouse reporting (code=(%s-32),row=%s,col=%s)',
+      '< CSI ?c'           : 'DA1 Response',
+      '< CSI >0;95;c'      : 'DA2 Response: xterm patch#95 (could be iTerm/iTerm2)',
+      '> CSI @'            : 'ICH / insert blank characters',
+      '> CSI [2]H'         : 'CUP / move cursor to (row=%s, col=%s)',
+      '> CSI >2T'          : 'Title Mode - Reset (xterm) 2: Do not set window/icon labels using UTF-8',
+    }
 
 if __name__ == "__main__":
     import doctest
